@@ -3,25 +3,27 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module Config
-  RUBY_VERSION == "1.8.6" or
-    raise "ruby lib version (1.8.6) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.8.7" or
+    raise "ruby lib version (1.8.7) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/alpha-openbsd4.7")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/alpha-openbsd4.9")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
+  CONFIG["PATCHLEVEL"] = "330"
   CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
-  CONFIG["ruby_install_name"] = "ruby"
-  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
-  CONFIG["RUBY_SO_NAME"] = "ruby"
-  CONFIG["MANTYPE"] = "doc"
-  CONFIG["NROFF"] = "/usr/bin/nroff"
-  CONFIG["configure_args"] = " '--enable-shared' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' 'CC=cc' 'CFLAGS=-O2 -pipe' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE' 'YACC=yacc'"
-  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["sitearch"] = "alpha-openbsd4.7"
-  CONFIG["arch"] = "alpha-openbsd4.7"
+  CONFIG["ruby_install_name"] = "ruby18"
+  CONFIG["RUBY_INSTALL_NAME"] = "ruby18"
+  CONFIG["RUBY_SO_NAME"] = "ruby18"
+  CONFIG["MANTYPE"] = "man"
+  CONFIG["NROFF"] = "/bin/false"
+  CONFIG["configure_args"] = " '--program-suffix=18' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'YACC=yacc'"
+  CONFIG["vendordir"] = "$(libdir)/ruby/vendor_ruby"
+  CONFIG["sitedir"] = "$(libdir)/ruby/site_ruby"
+  CONFIG["sitearch"] = "alpha-openbsd4.9"
+  CONFIG["arch"] = "alpha-openbsd4.9"
   CONFIG["MAKEFILES"] = "Makefile"
   CONFIG["EXPORT_PREFIX"] = ""
   CONFIG["COMMON_HEADERS"] = ""
@@ -36,20 +38,20 @@ module Config
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.2.0"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.0.0"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
   CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared  -fPIC"
-  CONFIG["XLDFLAGS"] = ""
-  CONFIG["XCFLAGS"] = " -DRUBY_EXPORT"
+  CONFIG["debugflags"] = ""
+  CONFIG["optflags"] = ""
+  CONFIG["cflags"] = "$(optflags) $(debugflags)"
+  CONFIG["cppflags"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include"
   CONFIG["RDOCTARGET"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["EXTOUT"] = ".ext"
-  CONFIG["RUNRUBY"] = "$(MINIRUBY) $(srcdir)/runruby.rb --extout=$(EXTOUT) --"
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
-  CONFIG["MINIRUBY"] = "./miniruby$(EXEEXT)"
   CONFIG["setup"] = "Setup"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip"
@@ -92,23 +94,23 @@ module Config
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "cc -E"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE $(DEFS)"
-  CONFIG["LDFLAGS"] = "-L.  -Wl,-E"
-  CONFIG["CFLAGS"] = "-mieee -O2 -pipe  -fPIC"
+  CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include $(DEFS) $(cppflags)"
+  CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -Wl,-E"
+  CONFIG["CFLAGS"] = "-mieee -O2 -pipe  -fPIC $(cflags)"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd4.7"
+  CONFIG["target_os"] = "openbsd4.9"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "alpha"
-  CONFIG["target"] = "alpha-unknown-openbsd4.7"
-  CONFIG["host_os"] = "openbsd4.7"
+  CONFIG["target"] = "alpha-unknown-openbsd4.9"
+  CONFIG["host_os"] = "openbsd4.9"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "alpha"
-  CONFIG["host"] = "alpha-unknown-openbsd4.7"
-  CONFIG["build_os"] = "openbsd4.7"
+  CONFIG["host"] = "alpha-unknown-openbsd4.9"
+  CONFIG["build_os"] = "openbsd4.9"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "alpha"
-  CONFIG["build"] = "alpha-unknown-openbsd4.7"
-  CONFIG["TEENY"] = "6"
+  CONFIG["build"] = "alpha-unknown-openbsd4.9"
+  CONFIG["TEENY"] = "7"
   CONFIG["MINOR"] = "8"
   CONFIG["MAJOR"] = "1"
   CONFIG["target_alias"] = ""
@@ -139,6 +141,7 @@ module Config
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
   CONFIG["exec_prefix"] = "$(prefix)"
+  CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
   CONFIG["PACKAGE_STRING"] = ""
   CONFIG["PACKAGE_VERSION"] = ""
@@ -151,6 +154,8 @@ module Config
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
+  CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
+  CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["topdir"] = File.dirname(__FILE__)
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
