@@ -201,7 +201,7 @@ module FileUtils
     list.map {|path| path.sub(%r</\z>, '') }.each do |path|
       # optimize for the most common case
       begin
-        fu_mkdir path, options[:mode]
+        fu_mkdir path, options[:mode] unless File.directory?(path)
         next
       rescue SystemCallError
         next if File.directory?(path)
@@ -214,7 +214,7 @@ module FileUtils
       end
       stack.reverse_each do |path|
         begin
-          fu_mkdir path, options[:mode]
+          fu_mkdir path, options[:mode] unless File.directory?(path)
         rescue SystemCallError => err
           raise unless File.directory?(path)
         end
@@ -236,7 +236,6 @@ module FileUtils
 
   def fu_mkdir(path, mode)   #:nodoc:
     path = path.sub(%r</\z>, '')
-    return true if File.exist?(path)
     if mode
       Dir.mkdir path, mode
       File.chmod mode, path
@@ -419,6 +418,7 @@ module FileUtils
     fu_check_options options, OPT_TABLE['cp_r']
     fu_output_message "cp -r#{options[:preserve] ? 'p' : ''}#{options[:remove_destination] ? ' --remove-destination' : ''} #{[src,dest].flatten.join ' '}" if options[:verbose]
     return if options[:noop]
+    options = options.dup
     options[:dereference_root] = true unless options.key?(:dereference_root)
     fu_each_src_dest(src, dest) do |s, d|
       copy_entry s, d, options[:preserve], options[:dereference_root], options[:remove_destination]
@@ -985,6 +985,7 @@ module FileUtils
 
     def fu_get_gid(group)   #:nodoc:
       return nil unless group
+      group = group.to_s
       if /\A\d+\z/ =~ group
       then group.to_i
       else Etc.getgrnam(group).gid
