@@ -1,8 +1,10 @@
+/* confdefs.h */
 #define PACKAGE_NAME ""
 #define PACKAGE_TARNAME ""
 #define PACKAGE_VERSION ""
 #define PACKAGE_STRING ""
 #define PACKAGE_BUGREPORT ""
+#define PACKAGE_URL ""
 #define OLD_YACC 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -19,11 +21,6 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
-#define __EXTENSIONS__ 1
-#define _ALL_SOURCE 1
-#define _GNU_SOURCE 1
-#define _POSIX_PTHREAD_SEMANTICS 1
-#define _TANDEM_SOURCE 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
 #define SIZEOF_INT 4
@@ -71,6 +68,7 @@
 #define HAVE_FLOAT_H 1
 #define HAVE_IEEEFP_H 1
 #define HAVE_PTHREAD_H 1
+#define HAVE_TIME_H 1
 #define SIZEOF_RLIM_T 8
 #define HAVE_STRUCT_STAT_ST_BLKSIZE 1
 #define HAVE_ST_BLKSIZE 1
@@ -78,6 +76,23 @@
 #define HAVE_ST_BLOCKS 1
 #define HAVE_STRUCT_STAT_ST_RDEV 1
 #define HAVE_ST_RDEV 1
+#define HAVE_INT8_T 1
+#define SIZEOF_INT8_T 1
+#define HAVE_UINT8_T 1
+#define SIZEOF_UINT8_T 1
+#define HAVE_INT16_T 1
+#define SIZEOF_INT16_T 2
+#define HAVE_UINT16_T 1
+#define SIZEOF_UINT16_T 2
+#define HAVE_INT32_T 1
+#define SIZEOF_INT32_T 4
+#define HAVE_UINT32_T 1
+#define SIZEOF_UINT32_T 4
+#define HAVE_INT64_T 1
+#define SIZEOF_INT64_T 8
+#define HAVE_UINT64_T 1
+#define SIZEOF_UINT64_T 8
+#define HAVE_STRUCT_TIMEZONE 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_ALLOCA 1
@@ -144,7 +159,9 @@
 #define HAVE_DLOPEN 1
 #define HAVE_SIGPROCMASK 1
 #define HAVE_SIGACTION 1
+#define HAVE_SIGSETJMP 1
 #define HAVE__SETJMP 1
+#define HAVE__LONGJMP 1
 #define HAVE_SETSID 1
 #define HAVE_TELLDIR 1
 #define HAVE_SEEKDIR 1
@@ -160,6 +177,9 @@
 #define HAVE_SETGID 1
 #define HAVE_SETENV 1
 #define HAVE_UNSETENV 1
+#define RUBY_SETJMP(env) _setjmp(env)
+#define RUBY_LONGJMP(env,val) _longjmp(env,val)
+#define RUBY_JMP_BUF jmp_buf
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
@@ -181,6 +201,9 @@
 #define RUBY_LIB "/usr/local/lib/ruby/1.8"
 #define RUBY_SITE_LIB "/usr/local/lib/ruby/site_ruby"
 #define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.8"
-#define RUBY_PLATFORM "sparc64-openbsd4.6"
-#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/sparc64-openbsd4.6"
-#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/sparc64-openbsd4.6"
+#define RUBY_VENDOR_LIB "/usr/local/lib/ruby/vendor_ruby"
+#define RUBY_VENDOR_LIB2 "/usr/local/lib/ruby/vendor_ruby/1.8"
+#define RUBY_PLATFORM "sparc64-openbsd4.9"
+#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/sparc64-openbsd4.9"
+#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/sparc64-openbsd4.9"
+#define RUBY_VENDOR_ARCHLIB "/usr/local/lib/ruby/vendor_ruby/1.8/sparc64-openbsd4.9"
